@@ -4,31 +4,38 @@ from collections import OrderedDict
 
 import pandas as pd
 
+from . import utils
 from . import DateTimeColumn, IntColumn, FloatColumn, TextColumn
 from . import OrderColumn, CategoricalColumn
 from . import DataLabelerColumn
 from .profiler_options import StructuredOptions
 
+import multiprocessing as mp
 
 class BaseColumnProfileCompiler(with_metaclass(abc.ABCMeta, object)):
 
     # NOTE: these profilers are ordered. Test functionality if changed.
     _profilers = list()
 
-    def __init__(self, df_series, options=None):
+    def __repr__(self):
+        return self.__class__.__name__
+
+    def __init__(self, df_series, options=None, pool=None):
         if not self._profilers:
             raise NotImplementedError("Must add profilers.")
 
         self.name = df_series.name
         self._profiles = OrderedDict()
-        self._create_profile(df_series, options)
+        self._create_profile(df_series, options, pool)
 
+        
     @property
     @abc.abstractmethod
     def profile(self):
         raise NotImplementedError()
 
-    def _create_profile(self, df_series, options=None):
+    
+    def _create_profile(self, df_series, options=None, pool=None):
         """
         Initializes and evaluates all profilers for the given dataframe.
         
@@ -40,42 +47,33 @@ class BaseColumnProfileCompiler(with_metaclass(abc.ABCMeta, object)):
         :rtype: None
         """
 
-        # convert all the values to string
-        df_series = df_series.apply(str)
-        
+        if len(self._profilers) == 0:
+            return
+
         selected_col_profiles = None
         if options and isinstance(options, StructuredOptions):
             selected_col_profiles = options.enabled_columns
 
+        # Create profiles
         for col_profile_type in self._profilers:
+            
             # Create profile if options allow for it or if there are no options
             if selected_col_profiles is None or \
-                    col_profile_type.col_type in selected_col_profiles:
-                col_profile_options = None
-                if options and options.properties[col_profile_type.col_type]:
-                    col_profile_options = options.properties[col_profile_type.col_type]
+               col_profile_type.col_type in selected_col_profiles:
 
+                col_options = None
+                if options and options.properties[col_profile_type.col_type]:
+                    col_options = options.properties[col_profile_type.col_type]
+                    
                 try:
                     self._profiles[col_profile_type.col_type] = \
-                        col_profile_type(df_series.name, options=col_profile_options)
-                    self._profiles[col_profile_type.col_type].update(df_series)
+                        col_profile_type(df_series.name, options=col_options)
                 except Exception as e:
-                    import warnings
-                    warning_msg = "\n\n!!! WARNING Partial Profiler Failure !!!\n\n"
-                    warning_msg += "Profiling Type: {}".format(col_profile_type.col_type)
-                    warning_msg += "\nException: {}".format(type(e).__name__)
-                    warning_msg += "\nMessage: {}".format(e)
+                    utils.warn_on_profile(col_profile_type.col_type, e)
 
-                    # This is considered a major error
-                    if type(e).__name__ == "ValueError":
-                        raise ValueError(e)
-                    
-                    warning_msg += "\n\nFor labeler errors, try installing "
-                    warning_msg += "the extra ml requirements via:\n\n"
-                    warning_msg += "$ pip install dataprofiler[ml] --user\n\n"
-
-                    warnings.warn(warning_msg, RuntimeWarning, stacklevel=2)
-            
+        # Update profile after creation
+        self.update_profile(df_series, pool)
+                        
 
     def __add__(self, other):
         """
@@ -104,22 +102,68 @@ class BaseColumnProfileCompiler(with_metaclass(abc.ABCMeta, object)):
             )
         return merged_profile_compiler
 
-    def update_profile(self, df_series):
-        """
-        Initializes the profiles the column dataframe.
-        
-        :param df_series: a given column
-        :type df_series: pandas.core.series.Series
-        :return: None
-        :rtype: None
-        """
-        df_series = df_series.apply(str)
-        for column_profile in self._profiles:
-            self._profiles[column_profile].update(df_series)
 
+    def update_profile(self, df_series, pool=None):
+        """
+        Updates the profiles from the data frames
+        
+        :param df_series: a given column, assume df_series in str
+        :type df_series: pandas.core.series.Series
+        :param pool: pool to utilized for multiprocessing
+        :type pool: multiprocessing.Pool
+        :return: Self
+        :rtype: BaseColumnProfileCompiler
+        """
+        
+        if len(self._profilers) == 0:
+            return 
+        
+        # If single process, loop and return
+        if pool is None:
+            for col_profile in self._profiles:
+                self._profiles[col_profile].update(df_series)
+            return self
+        
+        # If multiprocess, setup pool, etc
+        single_process_list = []
+        multi_process_dict = {}
+        
+        # Spin off seperate processes, where possible
+        for col_profile in self._profiles:
+            
+            if self._profiles[col_profile].thread_safe:
+                
+                try: # Add update function to be applied on the pool
+                    multi_process_dict[col_profile] = pool.apply_async(
+                        self._profiles[col_profile].update, (df_series,))
+                except Exception as e: # Attempt again as a single process
+                    self._profiles[col_profile].thread_safe = False
+                
+            if not self._profiles[col_profile].thread_safe:                
+                single_process_list.append(col_profile)
+
+        # Single process thread to loop through any known unsafe
+        for col_profile in single_process_list:
+            self._profiles[col_profile].update(df_series)
+                
+        # Loop through remaining multiprocesses and close them out
+        single_process_list = []
+        for col_profile in multi_process_dict.keys():
+            try:
+                returned_profile = multi_process_dict[col_profile].get()
+                if returned_profile is not None:
+                    self._profiles[col_profile] = returned_profile
+            except Exception as e: # Attempt again as a single process
+                self._profiles[col_profile].thread_safe = False            
+                single_process_list.append(col_profile)                
+        
+        # Single process thread to loop through
+        for col_profile in single_process_list:
+            self._profiles[col_profile].update(df_series)
+        return self
 
 class ColumnPrimitiveTypeProfileCompiler(BaseColumnProfileCompiler):
-
+    
     # NOTE: these profilers are ordered. Test functionality if changed.
     _profilers = [
         DateTimeColumn,
@@ -136,14 +180,13 @@ class ColumnPrimitiveTypeProfileCompiler(BaseColumnProfileCompiler):
             "statistics": dict()
         }
         has_found_match = False
+        
         for _, profiler in self._profiles.items():
             if not has_found_match and profiler.data_type_ratio == 1.0:
-                profile.update(
-                    {
-                        "data_type": profiler.col_type,
-                        "statistics": profiler.profile,
-                    }
-                )
+                profile.update({
+                    "data_type": profiler.col_type,
+                    "statistics": profiler.profile,
+                })
                 has_found_match = True
             profile["data_type_representation"].update(
                 dict([(profiler.col_type, profiler.data_type_ratio)])
