@@ -15,6 +15,8 @@ import hashlib
 from collections import OrderedDict
 import warnings
 
+import multiprocessing as mp
+
 import pandas as pd
 
 from . import utils
@@ -26,14 +28,13 @@ from .helpers.report_helpers import calculate_quantiles, _prepare_report
 from .profiler_options import ProfilerOptions, StructuredOptions, \
     DataLabelerOptions
 
-
 class StructuredDataProfile(object):
 
     def __init__(self, df_series, sample_size=None, min_sample_size=5000,
                  sampling_ratio=0.2, min_true_samples=None,
-                 options=None):
+                 sample_ids=None, pool=None, options=None):
         """
-        Instantiate the Structured Profiler class.
+        Instantiate the Structured Profiler class for a given column.
         
         :param df_series: Data to be profiled
         :type df_series: pandas.core.series.Series
@@ -42,6 +43,10 @@ class StructuredDataProfile(object):
         :param min_true_samples: Minimum number of samples required for the
             profiler
         :type min_true_samples: int
+        :param sample_ids: Randomized list of sample indices
+        :type sample_ids: list(list)
+        :param pool: pool utilized for multiprocessing
+        :type pool: multiprocessing.Pool
         :param options: Options for the structured profiler.
         :type options: StructuredOptions Object
         """
@@ -65,6 +70,7 @@ class StructuredDataProfile(object):
         self.null_count = 0
         self.null_types = list()
         self.null_types_index = {}
+                
         if not sample_size:
             sample_size = self._get_sample_size(df_series)
         if sample_size < len(df_series):
@@ -72,23 +78,28 @@ class StructuredDataProfile(object):
                           "All statistics will be based on this subsample and "
                           "not the whole dataset.".format(sample_size))
         clean_sampled_df, base_stats = \
-            self.get_base_props_and_clean_null_params(df_series, sample_size)
+            self.get_base_props_and_clean_null_params(
+                df_series, sample_size, sample_ids=sample_ids)
         self._update_base_stats(base_stats)
+
         self.profiles = {
             'data_type_profile':
-                ColumnPrimitiveTypeProfileCompiler(clean_sampled_df,
-                                                   self.options),
+            ColumnPrimitiveTypeProfileCompiler(
+                clean_sampled_df, self.options, pool),
             'data_stats_profile':
-                ColumnStatsProfileCompiler(clean_sampled_df, self.options)}
+            ColumnStatsProfileCompiler(
+                clean_sampled_df, self.options, pool)
+        }
 
         use_data_labeler = True
         if options and isinstance(options, StructuredOptions):
             use_data_labeler = options.data_labeler.is_enabled
 
         if use_data_labeler:
-            self.profiles.update(
-                {'data_label_profile':
-                     ColumnDataLabelerCompiler(clean_sampled_df, self.options)})
+            self.profiles.update({
+                'data_label_profile':
+                ColumnDataLabelerCompiler(clean_sampled_df, self.options)
+            })
 
     def __add__(self, other):
         """
@@ -143,6 +154,7 @@ class StructuredDataProfile(object):
             "column_name": self.name,
             "samples": self.sample,
         })
+                
         if unordered_profile.get("data_type", None) is not None:
             unordered_profile["statistics"].update({
                 "sample_size": self.sample_size,
@@ -150,8 +162,7 @@ class StructuredDataProfile(object):
                 "null_types": self.null_types,
                 "null_types_index": self.null_types_index,
                 "data_type_representation":
-                    unordered_profile["data_type_representation"],
-                "data_label_probability": None,
+                    unordered_profile["data_type_representation"]
             })
 
         dict_order = [
@@ -171,70 +182,77 @@ class StructuredDataProfile(object):
                 profile[key] = unordered_profile[key]
             except KeyError as e:
                 profile[key] = None
-                print(f"Error: {key} has no data")
 
         return profile
-
-    @staticmethod
-    def _combine_unique_sets(a, b):
-        """
-        Method to union two lists.
-        
-        :type a: list
-        :type b: list
-        :rtype: list
-        """
-        if not a and not b:
-            return list()
-        elif not a:
-            return b
-        elif not b:
-            return a
-        return list(OrderedDict.fromkeys(a + b))
-
+    
     def _update_base_stats(self, base_stats):
         self.sample_size += base_stats["sample_size"]
         self.sample = base_stats["sample"]
         self.null_count += base_stats["null_count"]
-        self.null_types = self._combine_unique_sets(
+        self.null_types = utils._combine_unique_sets(
             self.null_types, list(base_stats["null_types"].keys())
         )
 
         for null_type, null_rows in base_stats["null_types"].items():
             if type(null_rows) is list:
                 null_rows.sort()
-            self.null_types_index.setdefault(null_type, []).extend(null_rows)
+            self.null_types_index.setdefault(null_type, set()).update(null_rows)
 
-    def update_profile(self, df_series, sample_size=None, min_true_samples=None):
+
+    def update_profile(self, df_series, sample_size=None,
+                       min_true_samples=None, sample_ids=None,
+                       pool=None):
+        """
+        Update the column profiler
+        
+        :param df_series: Data to be profiled
+        :type df_series: pandas.core.series.Series
+        :param sample_size: Number of samples to use in generating profile
+        :type sample_size: int
+        :param min_true_samples: Minimum number of samples required for the
+            profiler
+        :type min_true_samples: int
+        :param sample_ids: Randomized list of sample indices
+        :type sample_ids: list(list)
+        :param pool: pool utilized for multiprocessing
+        :type pool: multiprocessing.Pool        
+        """
         if not sample_size:
             sample_size = len(df_series)
         if not sample_size:
             sample_size = self._get_sample_size(df_series)
         clean_sampled_df, base_stats = \
             self.get_base_props_and_clean_null_params(
-                df_series, sample_size, min_true_samples=min_true_samples)
+                df_series, sample_size,
+                min_true_samples=min_true_samples,
+                sample_ids=sample_ids
+            )
         self._update_base_stats(base_stats)
+
+        # Profile compilers being updated
         for profile in self.profiles.values():
-            profile.update_profile(clean_sampled_df)
+            profile.update_profile(clean_sampled_df, pool)
+
 
     def _get_sample_size(self, df_series):
         """
         Determines the minimum sampling size for detecting column type.
-        
+
         :param df_series: a column of data
         :type df_series: pandas.core.series.Series
         :return: integer sampling size
         :rtype: int
         """
         len_df = len(df_series)
-        if len_df < self._min_sample_size:
+        if len_df <= self._min_sample_size:
             return int(len_df)
         return max(int(self._sampling_ratio * len_df), self._min_sample_size)
 
     # TODO: flag column name with null values and potentially return row
     #  index number in the error as well
     def get_base_props_and_clean_null_params(self, df_series, sample_size,
-                                             min_true_samples=None):
+                                             min_true_samples=None,
+                                             sample_ids=None):
         """
         Identify null characters and return them in a dictionary as well as
         remove any nulls in column.
@@ -246,6 +264,8 @@ class StructuredDataProfile(object):
         :param min_true_samples: Minimum number of samples required for the
             profiler
         :type min_true_samples: int
+        :param sample_ids: Randomized list of sample indices
+        :type sample_ids: list(list)
         :return: updated column with null removed and dictionary of null
             parameters
         :rtype: pd.Series, dict
@@ -273,16 +293,21 @@ class StructuredDataProfile(object):
         # Pandas reads empty values in the csv files as nan
         df_series = df_series.apply(str)
 
-        sample_ind_generator = utils.shuffle_in_chunks(
-            len_df, chunk_size=sample_size)
-
+        # Select generator depending if sample_ids availablity
+        if sample_ids is None:
+            sample_ind_generator = utils.shuffle_in_chunks(
+                len_df, chunk_size=sample_size)
+        else:
+            sample_ind_generator = utils.partition(
+                sample_ids[0], chunk_size=sample_size)
+            
         na_columns = dict()
         true_sample_list = list()
         total_sample_size = 0
-        for sample_inds in sample_ind_generator:
-            total_sample_size += len(sample_inds)
+        for chunked_sample_ids in sample_ind_generator:
+            total_sample_size += len(chunked_sample_ids)
 
-            df_series_subset = df_series.iloc[sample_inds]
+            df_series_subset = df_series.iloc[chunked_sample_ids]
 
             query = '(' + '|'.join(null_values_and_flags.keys()) + ')'
             reg_ex_na = f"^{(query)}$"
@@ -305,7 +330,8 @@ class StructuredDataProfile(object):
                 break
             
         # close the generator in case it is not exhausted.
-        sample_ind_generator.close()
+        if sample_ids is None:
+            sample_ind_generator.close()
 
         df_series = df_series.loc[sorted(true_sample_list)]
         non_na = len(df_series)
@@ -352,12 +378,12 @@ class Profiler(object):
         
         profiler_options.validate()
         self.options = profiler_options
-            
+        self.total_samples = 0
         self.encoding = None
         self.file_type = None
-        self.null_in_row_count = 0
+        self.row_has_null_count = 0
+        self.row_is_null_count = 0
         self.hashed_row_dict = dict()
-        self.rows_ingested = 0
         self._samples_per_update = samples_per_update
         self._min_true_samples = min_true_samples
         self._profile = dict()
@@ -379,23 +405,7 @@ class Profiler(object):
                 self.options.set({'data_labeler.data_labeler_object': data_labeler})
                 
             except Exception as e:
-
-                import warnings
-                warning_msg = "\n\n!!! WARNING Partial Profiler Failure !!!\n\n"
-                warning_msg += "Profiling Type: {}".format('data_labeler')
-                warning_msg += "\nException: {}".format(type(e).__name__)
-                warning_msg += "\nMessage: {}".format(e)
-                
-                # This is considered a major error
-                if type(e).__name__ == "ValueError":
-                    raise ValueError(e)
-                
-                warning_msg += "\n\nFor labeler errors, try installing "
-                warning_msg += "the extra ml requirements via:\n\n"
-                warning_msg += "$ pip install dataprofiler[ml] --user\n\n"
-                
-                warnings.warn(warning_msg, RuntimeWarning, stacklevel=2)
-
+                utils.warn_on_profile('data_labeler', e)
                 self.options.set({'data_labeler.is_enabled': False})
 
         self.update_profile(data)
@@ -428,9 +438,11 @@ class Profiler(object):
             if self.encoding == other.encoding else 'multiple files'
         merged_profile.file_type = self.file_type \
             if self.file_type == other.file_type else 'multiple files'
-        merged_profile.null_in_row_count = \
-            self.null_in_row_count + other.null_in_row_count
-        merged_profile.rows_ingested = self.rows_ingested + other.rows_ingested
+        merged_profile.row_has_null_count = \
+            self.row_has_null_count + other.row_has_null_count
+        merged_profile.row_is_null_count = \
+            self.row_is_null_count + other.row_is_null_count
+        merged_profile.total_samples = self.total_samples + other.total_samples
         merged_profile.hashed_row_dict.update(self.hashed_row_dict)
         merged_profile.hashed_row_dict.update(other.hashed_row_dict)
 
@@ -444,27 +456,40 @@ class Profiler(object):
     def profile(self):
         return self._profile
 
+    @property
+    def _max_col_samples_used(self):
+        """
+        Calculates and returns the maximum samples used in any of the columns.
+        """
+        samples_used = 0
+        columns = list(self._profile.values())
+        for col in columns:
+            samples_used = max(samples_used, col.sample_size)
+        return samples_used
+
     def report(self, report_options=None):
         if not report_options:
             report_options = {
                 "output_format": None,
                 "num_quantile_groups": 4,
             }
-        output_format = report_options.get("output_format", None)
+            
+        output_format = report_options.get("output_format", None)        
+        omit_keys = report_options.get("omit_keys", [])
         num_quantile_groups = report_options.get("num_quantile_groups", 4)
 
         columns = list(self._profile.values())
         report = OrderedDict([
             ("global_stats", {
-                "samples_used": columns[0].sample_size if columns else 0,
+                "samples_used": self._max_col_samples_used,
                 "column_count": len(columns),
+                "row_count": self.total_samples,
+                "row_has_null_ratio": self._get_row_has_null_ratio(),
+                "row_is_null_ratio": self._get_row_is_null_ratio(),
                 "unique_row_ratio": self._get_unique_row_ratio(),
-                "row_has_null_ratio": self._get_null_row_ratio(),
                 "duplicate_row_count": self._get_duplicate_row_count(),
                 "file_type": self.file_type,
-                "encoding": self.encoding,
-                "data_classification": None,
-                "covariance": None,
+                "encoding": self.encoding
             }),
             ("data_stats", OrderedDict()),
         ])
@@ -476,18 +501,21 @@ class Profiler(object):
                 quantiles = calculate_quantiles(num_quantile_groups, quantiles)
                 report["data_stats"][key]["statistics"]["quantiles"] = quantiles
 
-        if output_format:
-            return _prepare_report(report, output_format=output_format)
-        return report
+        return _prepare_report(report, output_format, omit_keys)
 
     def _get_unique_row_ratio(self):
-        return len(self.hashed_row_dict) / self.rows_ingested
+        return len(self.hashed_row_dict) / self.total_samples
 
-    def _get_null_row_ratio(self):
-        return self.null_in_row_count / self.rows_ingested
+    def _get_row_is_null_ratio(self):
+        return 0 if self._max_col_samples_used == 0 \
+            else self.row_is_null_count / self._max_col_samples_used
+
+    def _get_row_has_null_ratio(self):
+        return 0 if self._max_col_samples_used == 0 \
+            else self.row_has_null_count / self._max_col_samples_used
 
     def _get_duplicate_row_count(self):
-        return self.rows_ingested - len(self.hashed_row_dict)
+        return self.total_samples - len(self.hashed_row_dict)
 
     def _update_row_statistics(self, data):
         """
@@ -500,11 +528,32 @@ class Profiler(object):
         :type data: pandas.DataFrame
         """
         
-        self.rows_ingested = len(data)
+        self.total_samples += len(data)
         self.hashed_row_dict = dict.fromkeys(
             pd.util.hash_pandas_object(data, index=False), True
         )
-        self.null_in_row_count = data.isnull().any(axis=1).sum()
+
+        # Calculate Null Column Count
+        null_rows = set()
+        null_in_row_count = set()
+        first_col_flag = True
+        for column in self._profile:
+            null_type_dict = self._profile[column].null_types_index
+            null_row_indices = set()
+            if null_type_dict:
+                null_row_indices = set.union(*null_type_dict.values())
+
+            # Find the common null indices between the columns
+            if first_col_flag:
+                null_rows = null_row_indices
+                null_in_row_count = null_row_indices
+                first_col_flag = False
+            else:
+                null_rows = null_rows.intersection(null_row_indices)
+                null_in_row_count = null_in_row_count.union(null_row_indices)
+
+        self.row_has_null_count += len(null_in_row_count)
+        self.row_is_null_count += len(null_rows)
         
     def update_profile(self, data, sample_size=None, min_true_samples=None):
         """
@@ -524,7 +573,6 @@ class Profiler(object):
             sample_size = self._samples_per_update
         if not min_true_samples:
             min_true_samples = self._min_true_samples
-
         if isinstance(data, data_readers.base_data.BaseData):
             self._profile = self._update_profile_from_chunk(
                 data.data, self._profile, sample_size, min_true_samples, self.options)
@@ -574,15 +622,35 @@ class Profiler(object):
             def tqdm(l):
                 for i, e in enumerate(l):
                     print("Processing Column {}/{}".format(i+1, len(l)))
-                    yield e
-			
+                    yield e                    
+
+        # Shuffle indices ones and share with columns
+        sample_ids = [*utils.shuffle_in_chunks(len(df), len(df))]
+
+        pool = None
+        if options.structured_options.multiprocess.is_enabled:
+            cpu_count = 1
+            try:
+                cpu_count = mp.cpu_count()
+            except NotImplementedError as e:
+                cpu_count = 1
+
+            # No additional advantage beyond 8 processes
+            # Always leave 1 cores free
+            if cpu_count > 2:
+                cpu_count = min(cpu_count-1, 8)
+                pool = mp.Pool(cpu_count)
+                print("Utilizing",cpu_count, "processes for profiling")
+        
         for col in tqdm(df.columns):
             if col in profile:
                 column_profile = profile[col]
                 column_profile.update_profile(
                     df[col],
                     sample_size=sample_size,
-                    min_true_samples=min_true_samples
+                    min_true_samples=min_true_samples,
+                    sample_ids=sample_ids,
+                    pool=pool
                 )
             else:
                 structured_options = None
@@ -592,8 +660,14 @@ class Profiler(object):
                     df[col],
                     sample_size=sample_size,
                     min_true_samples=min_true_samples,
+                    sample_ids=sample_ids,
+                    pool=pool,
                     options=structured_options
                 )
 
+        if pool is not None:
+            pool.close() # Close pool for new tasks
+            pool.join() # Wait for all workers to complete
+            
         return profile
 
