@@ -2,7 +2,8 @@ from .numerical_column_stats import NumericStatsMixin
 from .base_column_profilers import BaseColumnProfiler, \
     BaseColumnPrimitiveTypeProfiler
 from .profiler_options import TextOptions
-
+from . import utils
+import itertools
 
 class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
     """
@@ -70,7 +71,6 @@ class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
             min=self.min,
             max=self.max,
             mean=self.mean,
-            median=None,
             variance=self.variance,
             stddev=self.stddev,
             histogram=self.histogram_methods[histogram_method]['histogram'],
@@ -92,6 +92,7 @@ class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         """
         return 1.0 if self.sample_size else None
 
+    
     @BaseColumnProfiler._timeit(name='vocab')
     def _update_vocab(self, data, prev_dependent_properties=None,
                       subset_properties=None):
@@ -108,11 +109,10 @@ class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         :type subset_properties: dict
         :return: None
         """
-        vocab = []
-        for row in data:
-            row = list(row)
-            vocab = TextColumn._combine_unique_sets(vocab, row)
-        self.vocab = self._combine_unique_sets(self.vocab, vocab)
+        
+        data_flat = list(itertools.chain(*data))
+        self.vocab = utils._combine_unique_sets(self.vocab, data_flat)
+        
 
     def _update_helper(self, df_series_clean, profile):
         """
@@ -142,7 +142,8 @@ class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         """
         len_df = len(df_series)
         if len_df == 0:
-            return
+            return self
+        
         profile = dict(match_count=len_df, sample_size=len_df)
 
         BaseColumnProfiler._perform_property_calcs(
@@ -150,3 +151,5 @@ class TextColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
             prev_dependent_properties={}, subset_properties=profile)
 
         self._update_helper(df_series, profile)
+
+        return self
