@@ -243,7 +243,6 @@ class TestDateTimeColumnProfiler(unittest.TestCase):
         expected_profile = dict(
             min='03/10/13 15:43',
             max='Mar 11, 2013',
-            median=None,
             histogram=None,
             format=[
                 '%Y-%m-%d %H:%M:%S',
@@ -262,7 +261,7 @@ class TestDateTimeColumnProfiler(unittest.TestCase):
             expected = defaultdict(float, {'datetime': 1.0})
             self.assertEqual(expected, profiler.profile['times'])
             profile = profiler.profile
-            self.assertDictEqual(expected_profile, profile)
+            self.assertCountEqual(expected_profile, profile)
             
             # Validate time in datetime class has expected time after second
             # update
@@ -329,7 +328,7 @@ class TestDateTimeColumnProfiler(unittest.TestCase):
         self.assertEqual('Mar 12, 2013', merged_profile.max)
 
         # checks for date format merge
-        self.assertEqual(
+        self.assertCountEqual(
             ['%Y-%m-%d %H:%M:%S', '%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M:%S.%fZ',
              '%m/%d/%Y %H:%M', '%H:%M:%S.%f', '%b %d, %Y'],
             merged_profile.date_formats)
@@ -348,4 +347,4 @@ class TestDateTimeColumnProfiler(unittest.TestCase):
         with self.assertRaisesRegex(ValueError,
                                    "DateTimeColumn parameter 'options' must be"
                                    " of type DateTimeOptions."):
-            profiler = DateTimeColumn("Datetime", options="wrong_data_type")
\ No newline at end of file
+            profiler = DateTimeColumn("Datetime", options="wrong_data_type")
